BASTA: The BAyesian STellar Algorithm
#####################################

**Welcome to BASTA's documentation!**

BASTA is a Python-based fitting tool designed to determine properties of stars using a pre-computed grid of stellar
models. It calculates the probability density function of a given stellar property based on a set of observational
constraints defined by the user.

Current stable version: v1.5.1

*Please follow the repository on* `GitHub <https://github.com/BASTAcode/BASTA>`_ *to get notifications on new releases: Click "Watch" then "Custom" and tick "Releases.*



.. toctree::
   :maxdepth: 1
   :caption: Contents:

   install
   grids
   running
   examples
   methods
   controls
   troubleshoot
   contributing
   source_code


.. _ref_refs:

References and acknowledgements
*******************************

There are two articles containing the rationale, main features, and capabilities of the code:

* `The BASTA paper I <https://ui.adsabs.harvard.edu/abs/2015MNRAS.452.2127S/abstract>`_
* `The BASTA paper II <https://arxiv.org/abs/2109.14622>`_

Please consider citing these articles if you use BASTA in your work, and include the link to the code's repository
``https://github.com/BASTAcode/BASTA``.

Due to its versatility, BASTA is used in a large variety of studies requiring robust determination of fundamental
stellar properties. We have compiled a (non-exhaustive)
`list of papers using BASTA results <https://ui.adsabs.harvard.edu/public-libraries/x2tCt52HR_yqG-oaUabo_A>`_
that showcases these applications. If your paper using BASTA results is missing from the list please contact us.

.. _ref_authors:

Authors
*******
The current core developing team members are:

* Jakob Lysgaard Rørsted (maintainer)
* Mark Lykke Winther (co-maintainer)
* Amalie Stokholm (co-maintainer)
* Kuldeep Verma


The original author of the code is:

* Víctor Aguirre Børsen-Koch



Throughout the years, many people have contributed to the addition and development of various parts and modules of
BASTA. We welcome further contributions from the community as well as issues reporting. Please look at the section
:ref:`contrib` for further details.


Find what you are looking for
*****************************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
